@@ -61,19 +61,19 @@ async def retrieve(ansible_base_version: str,
                    ansible_base_source: t.Optional[str] = None,
                    collection_cache: t.Optional[str] = None) -> t.Dict[str, 'semver.Version']:
     """
-    Download ansible-base and the collections.
+    Download ansible-core and the collections.
 
     :arg ansible_base_version: Version of ansible-base/-core to download.
     :arg collections: Map of collection names to collection versions to download.
-    :arg tmp_dir: The directory to download into
+    :arg tmp_dir: The directory to download into.
     :arg galaxy_server: URL to the galaxy server.
-    :kwarg ansible_base_source: If given, a path to an Ansible-base checkout or expanded sdist.
-        This will be used instead of downloading an ansible-base package if the version matches
+    :kwarg ansible_base_source: If given, a path to an ansible-core checkout or expanded sdist.
+        This will be used instead of downloading an ansible-core package if the version matches
         with ``ansible_base_version``.
     :kwarg collection_cache: If given, a path to a directory containing collection tarballs.
         These tarballs will be used instead of downloading new tarballs provided that the
         versions match the criteria (latest compatible version known to galaxy).
-    :returns: Map of collection name to directory it is in.  ansible-base will
+    :returns: Map of collection name to directory it is in.  ansible-core will
         use the special key, `_ansible_base`.
     """
     collection_dir = os.path.join(tmp_dir, 'collections')
@@ -110,15 +110,21 @@ def normalize_plugin_info(plugin_type: str,
 
     :arg plugin_type: The type of plugins that we're getting docs for.
     :arg plugin_info: Mapping of plugin_info.  The toplevel keys are plugin names.
-        See the schema in :mod:`antsibull.schemas` for what the data should look like and just how
-        much conversion we can perform on it.
+        See the schema in :mod:`antsibull.schemas.docs` for what the data should look like and just
+        how much conversion we can perform on it.
     :returns: A tuple containing a "copy" of plugin_info with all of the data normalized and a list
         of nonfatal errors.  The plugin_info dict will follow the structure expressed in the schemas
-        in :mod:`antsibull.schemas`.  The nonfatal errors are strings representing the problems
+        in :mod:`antsibull.schemas.docs`.  The nonfatal errors are strings representing the problems
         encountered.
     """
-    new_info = {}
     errors = []
+    if plugin_type == 'role':
+        try:
+            return DOCS_SCHEMAS[plugin_type].parse_obj(plugin_info).dict(by_alias=True), errors
+        except ValidationError as e:
+            raise ValueError(str(e))
+
+    new_info = {}
     # Note: loop through "doc" before any other keys.
     for field in ('doc', 'examples', 'return'):
         try:
@@ -149,8 +155,8 @@ async def normalize_all_plugin_info(plugin_info: t.Mapping[str, t.Mapping[str, t
     Normalize the data in plugin_info so that it is ready to be passed to the templates.
 
     :arg plugin_info: Mapping of information about plugins.  This contains information about all of
-        the plugins that are to be documented. See the schema in :mod:`antsibull.schemas` for the
-        structure of the information.
+        the plugins that are to be documented. See the schema in :mod:`antsibull.schemas.docs` for
+        the structure of the information.
     :returns: A tuple of plugin_info (this is a "copy" of the input plugin_info with all of the
         data normalized) and a mapping of errors.  The plugin_info may have less records than the
         input plugin_info if there were plugin records which failed to validate.  The mapping of
@@ -224,8 +230,13 @@ def get_plugin_contents(plugin_info: t.Mapping[str, t.Mapping[str, t.Any]],
     for plugin_type, plugin_list in plugin_info.items():
         for plugin_name, plugin_desc in plugin_list.items():
             namespace, collection, short_name = get_fqcn_parts(plugin_name)
-            plugin_contents[plugin_type]['.'.join((namespace, collection))][short_name] = (
-                plugin_desc['doc']['short_description'])
+            if plugin_type == 'role':
+                desc = ''
+                if 'main' in plugin_desc['entry_points']:
+                    desc = plugin_desc['entry_points']['main']['short_description']
+            else:
+                desc = plugin_desc['doc']['short_description']
+            plugin_contents[plugin_type]['.'.join((namespace, collection))][short_name] = desc
 
     return plugin_contents
 
@@ -255,10 +266,10 @@ def get_collection_contents(plugin_content: t.Mapping[str, t.Mapping[str, t.Mapp
 def generate_docs_for_all_collections(venv: t.Union[VenvRunner, FakeVenvRunner],
                                       collection_dir: t.Optional[str],
                                       dest_dir: str,
-                                      flog,
                                       collection_names: t.Optional[t.List[str]] = None,
                                       create_indexes: bool = True,
-                                      squash_hierarchy: bool = False) -> None:
+                                      squash_hierarchy: bool = False,
+                                      breadcrumbs: bool = True) -> None:
     """
     Create documentation for a set of installed collections.
 
@@ -267,15 +278,18 @@ def generate_docs_for_all_collections(venv: t.Union[VenvRunner, FakeVenvRunner],
                          If ``None``, the collections are assumed to be in the current
                          search path for Ansible.
     :arg dest_dir: The directory into which the documentation is written.
-    :arg flog: A logger instance.
-    :arg collection_names: Optional list of collection names. If specified, only documentation
-                           for these collections will be collected and generated.
-    :arg create_indexes: Whether to create the collection index and plugin indexes. By default,
-                         they are created.
-    :arg squash_hierarchy: If set to ``True``, no directory hierarchy will be used.
-                           Undefined behavior if documentation for multiple collections are
-                           created.
+    :kwarg collection_names: Optional list of collection names. If specified, only documentation
+                             for these collections will be collected and generated.
+    :kwarg create_indexes: Whether to create the collection, namespace, and plugin indexes. By
+                           default, they are created.
+    :kwarg squash_hierarchy: If set to ``True``, no directory hierarchy will be used.
+                             Undefined behavior if documentation for multiple collections are
+                             created.
+    :kwarg breadcrumbs: Default True.  Set to False if breadcrumbs for collections should be
+        disabled.  This will disable breadcrumbs but save on memory usage.
     """
+    flog = mlog.fields(func='generate_docs_for_all_collections')
+    flog.notice('Begin')
 
     # Get the info from the plugins
     plugin_info, collection_metadata = asyncio_run(get_ansible_plugin_info(
@@ -290,18 +304,6 @@ def generate_docs_for_all_collections(venv: t.Union[VenvRunner, FakeVenvRunner],
     flog.notice('Finished loading collection routing information')
     # flog.fields(collection_routing=collection_routing).debug('Collection routing infos')
 
-    """
-    # Turn these into some sort of decorator that will choose to dump or load the values
-    # if a command line arg is specified.
-    with open('dump_raw_plugin_info.json', 'w') as f:
-        import json
-        json.dump(plugin_info, f)
-    flog.debug('Finished dumping raw plugin_info')
-    with open('dump_formatted_plugin_info.json', 'r') as f:
-        import json
-        plugin_info = json.load(f)
-    """
-
     remove_redirect_duplicates(plugin_info, collection_routing)
     stubs_info = find_stubs(plugin_info, collection_routing)
     # flog.fields(stubs_info=stubs_info).debug('Stubs info')
@@ -311,26 +313,6 @@ def generate_docs_for_all_collections(venv: t.Union[VenvRunner, FakeVenvRunner],
     augment_docs(plugin_info)
     flog.notice('Finished calculating new data')
 
-    """
-    with open('dump_normalized_plugin_info.json', 'w') as f:
-        json.dump(plugin_info, f)
-    flog.debug('Finished dumping normalized data')
-    with open('dump_errors.json', 'w') as f:
-        json.dump(nonfatal_errors, f)
-    flog.debug('Finished dump errors')
-    with open('dump_normalized_plugin_info.json', 'r') as f:
-        import json
-        plugin_info = json.load(f)
-    flog.debug('Finished loading normalized data')
-    with open('dump_errors.json', 'r') as f:
-        from collections import defaultdict
-        nonfatal_errors = json.load(f)
-        nonfatal_errors = defaultdict(lambda: defaultdict(list), nonfatal_errors)
-        for key, value in nonfatal_errors.items():
-            nonfatal_errors[key] = defaultdict(list, value)
-    flog.debug('Finished loading errors')
-    """
-
     # Load collection extra docs data
     extra_docs_data = asyncio_run(load_collections_extra_docs(
         {name: data.path for name, data in collection_metadata.items()}))
@@ -348,9 +330,10 @@ def generate_docs_for_all_collections(venv: t.Union[VenvRunner, FakeVenvRunner],
     # Only build top-level index if requested
     if create_indexes:
         asyncio_run(output_collection_index(
-            collection_to_plugin_info, collection_namespaces, dest_dir))
+            collection_to_plugin_info, collection_namespaces, dest_dir, breadcrumbs=breadcrumbs))
         flog.notice('Finished writing collection index')
-        asyncio_run(output_collection_namespace_indexes(collection_namespaces, dest_dir))
+        asyncio_run(output_collection_namespace_indexes(collection_namespaces, dest_dir,
+                                                        breadcrumbs=breadcrumbs))
         flog.notice('Finished writing collection namespace index')
         asyncio_run(output_plugin_indexes(plugin_contents, dest_dir))
         flog.notice('Finished writing plugin indexes')
@@ -358,7 +341,8 @@ def generate_docs_for_all_collections(venv: t.Union[VenvRunner, FakeVenvRunner],
     asyncio_run(output_indexes(collection_to_plugin_info, dest_dir,
                                collection_metadata=collection_metadata,
                                squash_hierarchy=squash_hierarchy,
-                               extra_docs_data=extra_docs_data))
+                               extra_docs_data=extra_docs_data,
+                               breadcrumbs=breadcrumbs))
     flog.notice('Finished writing indexes')
 
     asyncio_run(output_all_plugin_stub_rst(stubs_info, dest_dir,
@@ -410,13 +394,13 @@ def generate_docs() -> int:
         # flog.fields(tarballs=collection_tarballs).debug('Download complete')
         flog.notice('Finished retrieving tarballs')
 
-        # Get the ansible-base location
+        # Get the ansible-core location
         try:
             ansible_base_path = collection_tarballs.pop('_ansible_base')
         except KeyError:
-            print('ansible-base did not download successfully')
+            print('ansible-core did not download successfully')
             return 3
-        flog.fields(ansible_base_path=ansible_base_path).info('ansible-base location')
+        flog.fields(ansible_base_path=ansible_base_path).info('ansible-core location')
 
         # Install the collections to a directory
 
@@ -432,11 +416,12 @@ def generate_docs() -> int:
         asyncio_run(install_together(collection_tarballs.values(), collection_install_dir))
         flog.notice('Finished installing collections')
 
-        # Create venv for ansible-base
-        venv = VenvRunner('ansible-base-venv', tmp_dir)
+        # Create venv for ansible-core
+        venv = VenvRunner('ansible-core-venv', tmp_dir)
         venv.install_package(ansible_base_path)
-        flog.fields(venv=venv).notice('Finished installing ansible-base')
+        flog.fields(venv=venv).notice('Finished installing ansible-core')
 
-        generate_docs_for_all_collections(venv, collection_dir, app_ctx.extra['dest_dir'], flog)
+        generate_docs_for_all_collections(venv, collection_dir, app_ctx.extra['dest_dir'],
+                                          breadcrumbs=app_ctx.breadcrumbs)
 
     return 0
