@@ -11,12 +11,12 @@ import aiofiles
 from . import app_context
 
 
-async def verify_hash(filename: str, hash: str, algorithm: str = 'sha256') -> bool:
+async def verify_hash(filename: str, hash_digest: str, algorithm: str = 'sha256') -> bool:
     """
     Verify whether a file has a given sha256sum.
 
     :arg filename: The file to verify the sha256sum of.
-    :arg hash: The hash that is expected.
+    :arg hash_digest: The hash that is expected.
     :kwarg algorithm: The hash algorithm to use.  This must be present in hashlib on this
         system.  The default is 'sha256'
     :returns: True if the hash matches, otherwise False.
@@ -29,7 +29,7 @@ async def verify_hash(filename: str, hash: str, algorithm: str = 'sha256') -> bo
         while chunk:
             hasher.update(chunk)
             chunk = await f.read(ctx.chunksize)
-    if hasher.hexdigest() != hash:
+    if hasher.hexdigest() != hash_digest:
         return False
 
     return True
