@@ -35,27 +35,24 @@ CollectionInfoT = t.Mapping[str, t.Mapping[str, t.Mapping[str, str]]]
 PluginCollectionInfoT = t.Mapping[str, t.Mapping[str, t.Mapping[str, str]]]
 
 
-ADD_TOCTREES = True
-
-
 async def copy_file(source_path: str, dest_path: str) -> None:
     """
     Copy content from one file to another.
 
-    Note that this implementation is somewhat naive: it reads the whole content of the source file
-    and then proceeds to write it to the destination file.
-
     :arg source_path: Source path. Must be a file.
     :arg dest_path: Destination path.
     """
     flog = mlog.fields(func='copy_file')
     flog.debug('Enter')
 
-    async with aiofiles.open(source_path, 'rb') as f:
-        content = await f.read()
-
-    async with aiofiles.open(dest_path, 'wb') as f:
-        await f.write(content)
+    lib_ctx = app_context.lib_ctx.get()
+    async with aiofiles.open(source_path, 'rb') as f_in:
+        async with aiofiles.open(dest_path, 'wb') as f_out:
+            # TODO: PY3.8: while chunk := await f.read(lib_ctx.chunksize)
+            chunk = await f_in.read(lib_ctx.chunksize)
+            while chunk:
+                await f_out.write(chunk)
+                chunk = await f_in.read(lib_ctx.chunksize)
 
     flog.debug('Leave')
 
@@ -110,15 +107,24 @@ async def write_plugin_rst(collection_name: str, collection_meta: AnsibleCollect
                         nonfatal_errors=nonfatal_errors
                         ).error('{plugin_name} did not return correct RETURN or EXAMPLES.',
                                 plugin_name=plugin_name)
-        plugin_contents = plugin_tmpl.render(
-            collection=collection_name,
-            collection_version=collection_meta.version,
-            plugin_type=plugin_type,
-            plugin_name=plugin_name,
-            doc=plugin_record['doc'],
-            examples=plugin_record['examples'],
-            returndocs=plugin_record['return'],
-            nonfatal_errors=nonfatal_errors)
+        if plugin_type == 'role':
+            plugin_contents = plugin_tmpl.render(
+                collection=collection_name,
+                collection_version=collection_meta.version,
+                plugin_type=plugin_type,
+                plugin_name=plugin_name,
+                entry_points=plugin_record['entry_points'],
+                nonfatal_errors=nonfatal_errors)
+        else:
+            plugin_contents = plugin_tmpl.render(
+                collection=collection_name,
+                collection_version=collection_meta.version,
+                plugin_type=plugin_type,
+                plugin_name=plugin_name,
+                doc=plugin_record['doc'],
+                examples=plugin_record['examples'],
+                returndocs=plugin_record['return'],
+                nonfatal_errors=nonfatal_errors)
 
     if path_override is not None:
         plugin_file = path_override
@@ -231,6 +237,7 @@ async def output_all_plugin_rst(collection_to_plugin_info: CollectionInfoT,
     env = doc_environment(('antsibull.data', 'docsite'))
     # Get the templates
     plugin_tmpl = env.get_template('plugin.rst.j2')
+    role_tmpl = env.get_template('role.rst.j2')
     error_tmpl = env.get_template('plugin-error.rst.j2')
 
     writers = []
@@ -238,6 +245,9 @@ async def output_all_plugin_rst(collection_to_plugin_info: CollectionInfoT,
     async with asyncio_pool.AioPool(size=lib_ctx.thread_max) as pool:
         for collection_name, plugins_by_type in collection_to_plugin_info.items():
             for plugin_type, plugins in plugins_by_type.items():
+                plugin_type_tmpl = plugin_tmpl
+                if plugin_type == 'role':
+                    plugin_type_tmpl = role_tmpl
                 for plugin_short_name, dummy_ in plugins.items():
                     plugin_name = '.'.join((collection_name, plugin_short_name))
                     writers.append(await pool.spawn(
@@ -245,8 +255,9 @@ async def output_all_plugin_rst(collection_to_plugin_info: CollectionInfoT,
                                          collection_metadata[collection_name],
                                          plugin_short_name, plugin_type,
                                          plugin_info[plugin_type].get(plugin_name),
-                                         nonfatal_errors[plugin_type][plugin_name], plugin_tmpl,
-                                         error_tmpl, dest_dir, squash_hierarchy=squash_hierarchy)))
+                                         nonfatal_errors[plugin_type][plugin_name],
+                                         plugin_type_tmpl, error_tmpl,
+                                         dest_dir, squash_hierarchy=squash_hierarchy)))
 
         # Write docs for each plugin
         await asyncio.gather(*writers)
@@ -293,18 +304,22 @@ async def output_all_plugin_stub_rst(stubs_info: t.Mapping[
 
 
 async def write_collection_list(collections: t.Iterable[str], namespaces: t.Iterable[str],
-                                template: Template, dest_dir: str) -> None:
+                                template: Template, dest_dir: str,
+                                breadcrumbs: bool = True) -> None:
     """
     Write an index page listing all of the collections.
 
     Each collection will link to an index page listing all content in the collection.
 
     :arg collections: Iterable of all the collection names.
+    :arg namespaces: Iterable of all namespace names.
     :arg template: A template to render the collection index.
     :arg dest_dir: The destination directory to output the index into.
+    :kwarg breadcrumbs: Default True.  Set to False if breadcrumbs for collections should be
+        disabled.  This will disable breadcrumbs but save on memory usage.
     """
     index_contents = template.render(
-        collections=collections, namespaces=namespaces, add_toctrees=ADD_TOCTREES)
+        collections=collections, namespaces=namespaces, breadcrumbs=breadcrumbs)
     index_file = os.path.join(dest_dir, 'index.rst')
 
     async with aiofiles.open(index_file, 'w') as f:
@@ -312,7 +327,8 @@ async def write_collection_list(collections: t.Iterable[str], namespaces: t.Iter
 
 
 async def write_collection_namespace_index(namespace: str, collections: t.Iterable[str],
-                                           template: Template, dest_dir: str) -> None:
+                                           template: Template, dest_dir: str,
+                                           breadcrumbs: bool = True) -> None:
     """
     Write an index page listing all of the collections for this namespace.
 
@@ -322,9 +338,11 @@ async def write_collection_namespace_index(namespace: str, collections: t.Iterab
     :arg collections: Iterable of all the collection names.
     :arg template: A template to render the collection index.
     :arg dest_dir: The destination directory to output the index into.
+    :kwarg breadcrumbs: Default True.  Set to False if breadcrumbs for collections should
+        be disabled.  This will disable breadcrumbs but save on memory usage.
     """
     index_contents = template.render(
-        namespace=namespace, collections=collections, add_toctrees=ADD_TOCTREES)
+        namespace=namespace, collections=collections, breadcrumbs=breadcrumbs)
     index_file = os.path.join(dest_dir, 'index.rst')
 
     async with aiofiles.open(index_file, 'w') as f:
@@ -357,7 +375,8 @@ async def write_plugin_lists(collection_name: str,
                              template: Template,
                              dest_dir: str,
                              collection_meta: AnsibleCollectionMetadata,
-                             extra_docs_data: CollectionExtraDocsInfoT) -> None:
+                             extra_docs_data: CollectionExtraDocsInfoT,
+                             breadcrumbs: bool = True) -> None:
     """
     Write an index page for each collection.
 
@@ -368,12 +387,14 @@ async def write_plugin_lists(collection_name: str,
     :arg dest_dir: The destination directory to output the index into.
     :arg collection_meta: Metadata for the collection.
     :arg extra_docs_data: Extra docs data for the collection.
+    :kwarg breadcrumbs: Default True.  Set to False if breadcrumbs for collections should be
+        disabled.  This will disable breadcrumbs but save on memory usage.
     """
     index_contents = template.render(
         collection_name=collection_name,
         plugin_maps=plugin_maps,
         collection_version=collection_meta.version,
-        add_toctrees=ADD_TOCTREES,
+        breadcrumbs=breadcrumbs,
         extra_docs_sections=extra_docs_data[0])
 
     # This is only safe because we made sure that the top of the directory tree we're writing to
@@ -387,14 +408,17 @@ async def write_plugin_lists(collection_name: str,
 
 async def output_collection_index(collection_to_plugin_info: CollectionInfoT,
                                   collection_namespaces: t.Mapping[str, t.List[str]],
-                                  dest_dir: str) -> None:
+                                  dest_dir: str,
+                                  breadcrumbs: bool = True) -> None:
     """
     Generate top-level collection index page for the collections.
 
-    :arg collection_to_plugin_info: Mapping of collection_name to Mapping of plugin_type to Mapping
-        of plugin_name to short_description.
+    :arg collection_to_plugin_info: Mapping of collection_name to Mapping of plugin_type to
+        Mapping of plugin_name to short_description.
     :arg collection_namespaces: Mapping from collection namespaces to list of collection names.
     :arg dest_dir: The directory to place the documentation in.
+    :kwarg breadcrumbs: Default True.  Set to False if breadcrumbs for collections should be
+        disabled.  This will disable breadcrumbs but save on memory usage.
     """
     flog = mlog.fields(func='output_collection_index')
     flog.debug('Enter')
@@ -411,18 +435,21 @@ async def output_collection_index(collection_to_plugin_info: CollectionInfoT,
     os.makedirs(collection_toplevel, mode=0o755, exist_ok=True)
 
     await write_collection_list(collection_to_plugin_info.keys(), collection_namespaces.keys(),
-                                collection_list_tmpl, collection_toplevel)
+                                collection_list_tmpl, collection_toplevel, breadcrumbs=breadcrumbs)
 
     flog.debug('Leave')
 
 
 async def output_collection_namespace_indexes(collection_namespaces: t.Mapping[str, t.List[str]],
-                                              dest_dir: str) -> None:
+                                              dest_dir: str,
+                                              breadcrumbs: bool = True) -> None:
     """
     Generate collection namespace index pages for the collections.
 
     :arg collection_namespaces: Mapping from collection namespaces to list of collection names.
     :arg dest_dir: The directory to place the documentation in.
+    :kwarg breadcrumbs: Default True.  Set to False if breadcrumbs for collections should be
+        disabled.  This will disable breadcrumbs but save on memory usage.
     """
     flog = mlog.fields(func='output_collection_namespace_indexes')
     flog.debug('Enter')
@@ -442,7 +469,8 @@ async def output_collection_namespace_indexes(collection_namespaces: t.Mapping[s
 
             writers.append(await pool.spawn(
                 write_collection_namespace_index(
-                    namespace, collection_names, collection_list_tmpl, namespace_dir)))
+                    namespace, collection_names, collection_list_tmpl, namespace_dir,
+                    breadcrumbs=breadcrumbs)))
 
         await asyncio.gather(*writers)
 
@@ -492,18 +520,20 @@ async def output_indexes(collection_to_plugin_info: CollectionInfoT,
                          collection_metadata: t.Mapping[str, AnsibleCollectionMetadata],
                          extra_docs_data: t.Mapping[str, CollectionExtraDocsInfoT],
                          squash_hierarchy: bool = False,
+                         breadcrumbs: bool = True
                          ) -> None:
     """
     Generate collection-level index pages for the collections.
 
-    :arg collection_to_plugin_info: Mapping of collection_name to Mapping of plugin_type to Mapping
-        of plugin_name to short_description.
+    :arg collection_to_plugin_info: Mapping of collection_name to Mapping of plugin_type to
+        Mapping of plugin_name to short_description.
     :arg dest_dir: The directory to place the documentation in.
     :arg collection_metadata: Dictionary mapping collection names to collection metadata objects.
     :arg extra_docs_data: Dictionary mapping collection names to CollectionExtraDocsInfoT.
-    :arg squash_hierarchy: If set to ``True``, no directory hierarchy will be used.
-                           Undefined behavior if documentation for multiple collections are
-                           created.
+    :kwarg squash_hierarchy: If set to ``True``, no directory hierarchy will be used.
+        Undefined behavior if documentation for multiple collections are created.
+    :kwarg breadcrumbs: Default True.  Set to False if breadcrumbs for collections should be
+        disabled.  This will disable breadcrumbs but save on memory usage.
     """
     flog = mlog.fields(func='output_indexes')
     flog.debug('Enter')
@@ -537,7 +567,8 @@ async def output_indexes(collection_to_plugin_info: CollectionInfoT,
             writers.append(await pool.spawn(
                 write_plugin_lists(collection_name, plugin_maps, collection_plugins_tmpl,
                                    collection_dir, collection_metadata[collection_name],
-                                   extra_docs_data[collection_name])))
+                                   extra_docs_data[collection_name],
+                                   breadcrumbs=breadcrumbs)))
 
         await asyncio.gather(*writers)
 
